AudioFrame

Struct AudioFrame 

pub struct AudioFrame { /* private fields */ }

Implementations

Source

impl AudioFrame

pub fn builder() -> AudioFrameBuilder

Create a builder for configuring an audio frame

pub fn sample_rate(&self) -> i32

Get the sample rate in Hz.

pub fn num_channels(&self) -> i32

Get the number of audio channels.

pub fn num_samples(&self) -> i32

Get the number of samples per channel.

pub fn timecode(&self) -> i64

Get the timecode.

A value of zero is passed through to the SDK as its default timestamp behavior.

pub fn timestamp(&self) -> i64

Get the timestamp.

A value of zero is passed through to the SDK as its default timestamp behavior.

pub fn format(&self) -> AudioFormat

Get the audio format.

pub fn channel_stride_in_bytes(&self) -> i32

Get the channel stride in bytes.

pub fn data(&self) -> &[f32]

Get audio data as 32-bit floats

pub fn data_mut(&mut self) -> &mut [f32]

Get mutable audio sample data without changing the validated layout.

pub fn replace_data(&mut self, data: Vec<f32>) -> Result<()>

Replace the owned audio data while preserving the validated layout.

Errors

Returns Error::InvalidFrame if data is not exactly the validated sample count.

pub fn metadata(&self) -> Option<&str>

Get frame metadata as UTF-8 text, if present.

pub fn set_metadata<S: Into<String>>( &mut self, metadata: Option<S>, ) -> Result<()>

Replace frame metadata.

Errors

Returns Error::InvalidCString if metadata contains an interior NUL byte, or Error::InvalidFrame if the emitted C string would exceed the metadata size cap.

pub fn channel_data(&self, channel: usize) -> Option<Vec<f32>>

Get audio data for a specific channel

Data is always stored in planar format internally. If AudioLayout::Interleaved was specified at build time, the data was converted to planar during construction.